col__start__tag = 'Á'
col__end__tag = 'À'
row__start__tag = 'É'
row__end__tag = 'È'
cel__end__tag = 'Ê'

start__tag = 'Á'
end__tag = 'À'
line__tag = "---"
child__end__tag = 'Ê'
devided__tag = '|'
value__child__tag = ':'

